function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var sortBy = _interopDefault(require('lodash/sortBy'));
var _styled = _interopDefault(require('styled-components'));
var lodash = require('lodash');
var reactUse = require('react-use');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var magnifyingGlassSVG = "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 20 19.8\">\n  <g class=\"react-panel-search-magnifying-glass\">\n    <path class=\"cls-2\" d=\"M4,14,0,18l1.8,1.8,4-4A5.17,5.17,0,0,1,4,14\" transform=\"translate(0 0)\" />\n    <path class=\"cls-2\" d=\"M11.7,15.2a6.92,6.92,0,0,1-6.8-7,6.77,6.77,0,0,1,6.64-6.9h.16a6.94,6.94,0,0,1,7,6.88v0a7.15,7.15,0,0,1-7,7M11.7,0A8.15,8.15,0,0,0,3.6,8.2h0a8.17,8.17,0,0,0,8,8.3h.06A8.41,8.41,0,0,0,20,8.2,8.26,8.26,0,0,0,11.7,0\"\n      transform=\"translate(0 0)\" />\n  </g>\n</svg>\n";
var chevronSVG = "<svg viewBox=\"0 0 9.25 5.39\" class=\"react-panel-search-chevron\"><polyline stroke-width=\"1.2\" fill=\"none\" points=\"8.88 0.38 4.64 4.62 0.39 0.38\"></polyline></svg>";

var SearchContainer = _styled.label.withConfig({
  displayName: "StandardSearch__SearchContainer",
  componentId: "sc-1wdgg71-0"
})(["position:relative;display:flex;"]);

var magnifyingGlassSize = 1.5;
var magnifyingGlassSpacing = 0.5;

var SearchIcon = _styled.div.withConfig({
  displayName: "StandardSearch__SearchIcon",
  componentId: "sc-1wdgg71-1"
})(["position:absolute;top:0;bottom:0;margin:auto ", "rem;width:", "rem;cursor:pointer;svg{width:100%;height:100%;path{fill:gray;}}"], magnifyingGlassSpacing, magnifyingGlassSize);

var SearchBar = _styled.input.withConfig({
  displayName: "StandardSearch__SearchBar",
  componentId: "sc-1wdgg71-2"
})(["width:100%;box-sizing:border-box;padding:0.5rem 0.5rem 0.5rem ", "rem;box-sizing:border-box;border:solid 1px #dfdfdf;font-size:1.2rem;font-weight:300;", " &:focus{&::placeholder{color:rgb(255,255,255);}}"], magnifyingGlassSize + magnifyingGlassSpacing * 2, function (_ref) {
  var $hasSelection = _ref.$hasSelection;
  return $hasSelection ? "&::placeholder {\n      color: rgb(0, 0, 0);\n    }" : '';
});

var DropDownIcon = _styled.div.withConfig({
  displayName: "StandardSearch__DropDownIcon",
  componentId: "sc-1wdgg71-3"
})(["position:absolute;top:3px;bottom:3px;right:2px;padding:0 0.4rem;background-color:#fff;border:none;width:", "rem;cursor:pointer;svg{width:100%;height:100%;polyline{stroke:gray;stroke-width:0.6px;}}"], magnifyingGlassSize);

var ClearButton = _styled.button.withConfig({
  displayName: "StandardSearch__ClearButton",
  componentId: "sc-1wdgg71-4"
})(["position:absolute;top:2px;bottom:2px;right:2px;line-height:0;font-size:1.2rem;padding:0.4rem;text-transform:uppercase;text-align:center;color:#696969;background-color:#fff;border:none;&:disabled{cursor:not-allowed;opacity:0.5;}&:hover{color:#908d8d;cursor:pointer;}"]);

var StandardSearch = function StandardSearch(props) {
  var placeholder = props.placeholder,
      setSearchQuery = props.setSearchQuery,
      initialQuery = props.initialQuery,
      type = props.type,
      onClear = props.onClear,
      hasSelection = props.hasSelection,
      handleKeyDown = props.handleKeyDown,
      onFocus = props.onFocus,
      neverEmpty = props.neverEmpty,
      focusOnRender = props.focusOnRender,
      isOpen = props.isOpen,
      setIsOpen = props.setIsOpen;
  var previousPlaceholder = reactUse.usePrevious(placeholder);
  var searchEl = React.useRef(null);
  var clearEl = React.useRef(null);
  var dropdownEl = React.useRef(null);
  var onChange = lodash.debounce(function () {
    if (searchEl !== null && searchEl.current !== null) {
      setSearchQuery(searchEl.current.value);

      if (clearEl && clearEl.current) {
        clearEl.current.style.display = !neverEmpty && (searchEl.current.value.length || hasSelection) ? 'block' : 'none';
      }

      if (dropdownEl && dropdownEl.current) {
        dropdownEl.current.style.display = !neverEmpty && (searchEl.current.value.length || hasSelection) ? 'none' : 'block';
      }
    }
  }, 400);

  var clearSearch = function clearSearch() {
    if (searchEl !== null && searchEl.current !== null) {
      searchEl.current.value = '';
      searchEl.current.focus();
      setSearchQuery(searchEl.current.value);
      onClear();
    }

    if (clearEl && clearEl.current && !neverEmpty) {
      clearEl.current.style.display = 'none';
    }

    if (dropdownEl && dropdownEl.current) {
      dropdownEl.current.style.display = 'block';
    }
  };

  React.useEffect(function () {
    var node = searchEl.current;

    if (node) {
      if (!node.value) {
        node.value = initialQuery;
      }

      if (clearEl && clearEl.current) {
        clearEl.current.style.display = !neverEmpty && (node.value.length || hasSelection) ? 'block' : 'none';
      }

      if (dropdownEl && dropdownEl.current) {
        dropdownEl.current.style.display = !neverEmpty && (node.value.length || hasSelection) ? 'none' : 'block';
      }

      if (node.value && hasSelection && previousPlaceholder !== placeholder) {
        node.value = '';
      }
    }
  }, [searchEl, initialQuery, hasSelection, placeholder, previousPlaceholder]);
  React.useEffect(function () {
    if (focusOnRender && searchEl && searchEl.current) {
      searchEl.current.focus();
    }
  }, [focusOnRender, searchEl]);

  var closeDropdown = function closeDropdown(e) {
    if (isOpen) {
      e.preventDefault();
      e.stopPropagation();
      document.activeElement.blur();
      setIsOpen(false);
    }
  };

  return React__default.createElement(SearchContainer, {
    className: 'react-panel-search-search-bar-container'
  }, React__default.createElement(SearchIcon, {
    className: 'react-panel-search-search-bar-search-icon',
    dangerouslySetInnerHTML: {
      __html: magnifyingGlassSVG
    }
  }), React__default.createElement(SearchBar, {
    className: 'react-panel-search-search-bar-input',
    ref: searchEl,
    type: type ? type : 'text',
    placeholder: placeholder,
    onChange: onChange,
    autoComplete: 'off',
    "$hasSelection": hasSelection,
    onKeyDown: handleKeyDown,
    onFocus: onFocus
  }), React__default.createElement(ClearButton, {
    className: 'react-panel-search-search-bar-clear-button',
    ref: clearEl,
    style: {
      display: 'none',
      marginRight: type === 'number' ? '1rem' : undefined
    },
    onClick: clearSearch
  }, "\xD7"), React__default.createElement(DropDownIcon, {
    ref: dropdownEl,
    className: 'react-panel-search-search-bar-dropdown-arrow',
    style: {
      display: 'block',
      transform: isOpen ? 'rotate(180deg)' : undefined
    },
    dangerouslySetInnerHTML: {
      __html: chevronSVG
    },
    onClick: closeDropdown
  }));
};

var chevronSVG$1 = "<svg viewBox=\"0 0 9.25 5.39\" class=\"react-panel-search-chevron\"><polyline stroke-width=\"1.2\" fill=\"none\" points=\"8.88 0.38 4.64 4.62 0.39 0.38\"></polyline></svg>";

var Container = _styled.div.withConfig({
  displayName: "Root__Container",
  componentId: "inl3ke-0"
})(["position:relative;width:100%;color:#333;ul{margin:0;padding:0;list-style:none;}li{li{button:before{content:'\u21B3';margin-right:0.5rem;}}}.react-panel-search-highlighted-item{background-color:#f3f3f3;}&.react-panel-search-has-selection{input::placeholder{opacity:1;}}"]);

var SearchBar$1 = _styled.div.withConfig({
  displayName: "Root__SearchBar",
  componentId: "inl3ke-1"
})(["position:relative;"]);

var SearchResults = _styled.div.withConfig({
  displayName: "Root__SearchResults",
  componentId: "inl3ke-2"
})(["position:absolute;width:100%;box-sizing:border-box;max-height:300px;overflow:auto;background-color:#fff;&:hover{.react-panel-search-highlighted-item:not(:hover){background-color:#fff;}}::-webkit-scrollbar{-webkit-appearance:none;width:7px;}::-webkit-scrollbar-thumb{border-radius:4px;background-color:rgba(0,0,0,.3);}::-webkit-scrollbar-track{background-color:rgba(0,0,0,.1);}"]);

var TitleOuter = _styled.div.withConfig({
  displayName: "Root__TitleOuter",
  componentId: "inl3ke-3"
})(["font-weight:600;padding:0.25rem 1.75rem 0.6rem;text-transform:uppercase;color:#444;font-size:0.85rem;"]);

var BreadCrumbOuter = _styled(TitleOuter).withConfig({
  displayName: "Root__BreadCrumbOuter",
  componentId: "inl3ke-4"
})(["&:hover{cursor:pointer;background-color:#f3f3f3;}"]);

var Title = _styled.div.withConfig({
  displayName: "Root__Title",
  componentId: "inl3ke-5"
})(["display:grid;grid-column-gap:0.5rem;grid-template-columns:auto 1fr;padding:0.35rem 0;border-bottom:solid 1px gray;"]);

var NavButton = _styled.button.withConfig({
  displayName: "Root__NavButton",
  componentId: "inl3ke-6"
})(["border:none;outline:none;display:flex;justify-content:center;height:100%;width:1.4rem;padding:0.25rem;background-color:transparent;&:hover{cursor:pointer;}&:focus{background-color:#f3f3f3;}svg{width:100%;height:100%;transform:rotate(90deg);polyline{stroke:gray;stroke-width:0.75px;}}"]);

var NextButton = _styled(NavButton).withConfig({
  displayName: "Root__NextButton",
  componentId: "inl3ke-7"
})(["grid-row:1;grid-column:2;position:relative;padding:0 0.25rem;height:1.5rem;background-color:#fff;margin:auto 1.75rem auto 0.75rem;&:hover{cursor:pointer;background-color:#f3f3f3;}svg{transform:rotate(-90deg);}"]);

var TraverseOnlyButton = _styled(NextButton).withConfig({
  displayName: "Root__TraverseOnlyButton",
  componentId: "inl3ke-8"
})(["background-color:transparent;pointer-events:none;"]);

var PanelItem = _styled.li.withConfig({
  displayName: "Root__PanelItem",
  componentId: "inl3ke-9"
})(["display:grid;grid-template-columns:1fr auto;"]);

var ButtonBase = _styled.button.withConfig({
  displayName: "Root__ButtonBase",
  componentId: "inl3ke-10"
})(["padding:0.75rem 4rem 0.75rem 2rem;font-size:0.8rem;background-color:#fff;border:none;outline:none;display:block;width:100%;text-align:left;box-sizing:border-box;&:hover,&:focus{cursor:pointer;background-color:#f3f3f3;}"]);

var NoResults = _styled.div.withConfig({
  displayName: "Root__NoResults",
  componentId: "inl3ke-11"
})(["padding:0.75rem 4rem 0.75rem 2rem;font-size:0.8rem;"]);

var PanelButton = _styled(ButtonBase).withConfig({
  displayName: "Root__PanelButton",
  componentId: "inl3ke-12"
})(["grid-row:1;grid-column:1 / 3;"]);

var SearchButton = _styled(ButtonBase).withConfig({
  displayName: "Root__SearchButton",
  componentId: "inl3ke-13"
})(["padding:0.6rem 0.75rem"]);

var Direction;

(function (Direction) {
  Direction["asc"] = "asc";
  Direction["desc"] = "desc";
})(Direction || (Direction = {}));

var Root = (function (props) {
  var levels = props.levels,
      onSelect = props.onSelect,
      selectedValue = props.selectedValue,
      topLevelTitle = props.topLevelTitle,
      disallowSelectionLevels = props.disallowSelectionLevels,
      onTraverseLevel = props.onTraverseLevel,
      onHover = props.onHover,
      defaultPlaceholderText = props.defaultPlaceholderText,
      showCount = props.showCount,
      resultsIdentation = props.resultsIdentation,
      neverEmpty = props.neverEmpty,
      maxResults = props.maxResults,
      focusOnRender = props.focusOnRender,
      noResultsFoundFormatter = props.noResultsFoundFormatter,
      topLevelItems = props.topLevelItems,
      matchingKeywordFormatter = props.matchingKeywordFormatter,
      onClose = props.onClose;
  var initialSelectedValue = selectedValue;

  if (neverEmpty) {
    if (levels.length && initialSelectedValue === null) {
      (function () {
        var i = 0;

        do {
          if (!disallowSelectionLevels || !disallowSelectionLevels.find(function (l) {
            return l === levels[i].level;
          }) && levels[i].data.length) {
            initialSelectedValue = levels[i].data[0];
            break;
          }

          i++;
        } while (i < levels.length);
      })();
    }
  }

  var previousSelectedValue = reactUse.usePrevious(selectedValue);

  var _useState = React.useState({
    level: levels[0].level,
    parent: null,
    selected: initialSelectedValue,
    searchQuery: '',
    highlightedIndex: 0,
    isOpen: false
  }),
      state = _useState[0],
      setState = _useState[1];

  var updateState = function updateState(newState) {
    setState(newState);
  };

  var clearSearch = function clearSearch() {
    var newSelected = neverEmpty ? state.selected : null;
    updateState({
      level: levels[0].level,
      parent: null,
      selected: newSelected,
      searchQuery: '',
      highlightedIndex: 0,
      isOpen: true
    });

    if (onSelect) {
      onSelect(newSelected);
    }
  };

  var selectDatum = function selectDatum(value) {
    updateState(_extends({}, state, {
      selected: value,
      isOpen: false,
      searchQuery: ''
    }));

    if (onSelect) {
      onSelect(value);
    }
  };

  React.useEffect(function () {
    if (previousSelectedValue && !selectedValue && !neverEmpty) {
      updateState(_extends({}, state, {
        selected: null,
        searchQuery: ''
      }));
    } else if (selectedValue) {
      var level = state.level;
      var _parent = state.parent;

      if (selectedValue.level !== null) {
        var levelIndex = levels.findIndex(function (d) {
          return d.level === selectedValue.level;
        });

        if (levelIndex < levels.length - 1) {
          level = levels[levelIndex + 1].level;
          _parent = selectedValue.id;
        }
      }

      updateState(_extends({}, state, {
        selected: selectedValue,
        level: level,
        parent: _parent
      }));
    }
  }, [selectedValue, previousSelectedValue]);

  var closeDropdown = function closeDropdown() {
    return setState(function (current) {
      return _extends({}, current, {
        highlightedIndex: 0,
        isOpen: false
      });
    });
  };

  var rootRef = React.useRef(null);
  React.useEffect(function () {
    var el;

    var preventClickFromPropagating = function preventClickFromPropagating(e) {
      if (state.isOpen) {
        e.stopPropagation();
      }
    };

    if (rootRef.current !== null) {
      el = rootRef.current;
      el.addEventListener('mousedown', preventClickFromPropagating);
    }

    document.addEventListener('mousedown', closeDropdown);
    return function () {
      document.removeEventListener('mousedown', closeDropdown);

      if (el) {
        el.removeEventListener('mousedown', preventClickFromPropagating);
      }
    };
  }, [rootRef, closeDropdown]);
  var resultsRef = React.useRef(null);
  React.useEffect(function () {
    var closeOnEsc = function closeOnEsc(e) {
      if (e.key === "Escape") {
        closeDropdown();
        var focusedElement = document.activeElement;

        if (focusedElement) {
          focusedElement.blur();
        }
      }
    };

    var node = resultsRef.current;

    if (node) {
      var liElms = Array.from(node.querySelectorAll('li .react-panel-search-list-item'));

      for (var _i = 0, _liElms = liElms; _i < _liElms.length; _i++) {
        var li = _liElms[_i];
        li.classList.remove('react-panel-search-highlighted-item');
      }

      if (liElms.length) {
        var index;

        if (state.highlightedIndex >= liElms.length) {
          index = Math.abs(state.highlightedIndex - liElms.length);
          updateState(_extends({}, state, {
            highlightedIndex: 0
          }));
        } else if (state.highlightedIndex < 0) {
          index = liElms.length + state.highlightedIndex;
          updateState(_extends({}, state, {
            highlightedIndex: liElms.length - 1
          }));
        } else {
          index = state.highlightedIndex;
        }

        liElms[index].classList.add('react-panel-search-highlighted-item');
        var highlightedTop = liElms[index].offsetTop;
        var highlightedBottom = highlightedTop + liElms[index].offsetHeight;
        var containerScrollTop = node.scrollTop;
        var containerScrollBottom = containerScrollTop + node.offsetHeight;

        if (highlightedBottom > containerScrollBottom) {
          node.scrollTop = highlightedBottom - node.offsetHeight;
        } else if (highlightedTop < liElms[index].offsetHeight) {
          node.scrollTop = 0;
        } else if (highlightedTop < containerScrollTop) {
          node.scrollTop = highlightedTop;
        }
      }

      document.addEventListener('keydown', closeOnEsc);
    }

    return function () {
      document.removeEventListener('keydown', closeOnEsc);
    };
  }, [state, resultsRef, closeDropdown]);
  var firstRender = React.useRef(true);
  React.useEffect(function () {
    if (firstRender.current) {
      firstRender.current = false;
    } else {
      if (!state.isOpen) {
        onClose();
      }
    }
  }, [state.isOpen, onClose, firstRender]);

  var onMouseLeave = function onMouseLeave() {
    if (onHover) {
      onHover(null);
    }
  };

  var listOutput;

  if (state.searchQuery.length) {
    var safeQuery = new RegExp(state.searchQuery.replace(/[^\w\s]/gi, '').trim(), 'gi');
    var filteredElms = [];
    var renderedIds = [];

    var getChildren = function getChildren(index, parent, depth) {
      var elms = [];
      sortBy(levels[index].data, ['name']).forEach(function (child) {
        if (!maxResults || renderedIds.length < maxResults) {
          var keywordMatch;
          var keywordResultElm;

          if (child.keywords && child.keywords.length) {
            var matchingKeywords = child.keywords.filter(function (k) {
              return k.toLowerCase().includes(state.searchQuery.toLowerCase());
            });
            var nonMatchingKeywords = child.keywords.filter(function (k) {
              return !k.toLowerCase().includes(state.searchQuery.toLowerCase());
            });
            keywordMatch = matchingKeywords.length !== 0;
            keywordResultElm = matchingKeywordFormatter ? matchingKeywordFormatter(matchingKeywords, nonMatchingKeywords, state.searchQuery) : null;
          } else {
            keywordMatch = false;
            keywordResultElm = null;
          }

          if (child.parent_id === parent && !renderedIds.includes(child.id) && (child.title.toLowerCase().includes(state.searchQuery.toLowerCase()) || keywordMatch)) {
            renderedIds.push(child.id);
            var childElms;

            if (levels[index + 1] && levels[index + 1].data) {
              childElms = getChildren(index + 1, child.id, depth + 1);
            } else {
              childElms = null;
            }

            var childList = childElms && childElms.length ? React__default.createElement("ul", {
              className: 'react-panel-search-list-inner-container'
            }, childElms) : null;

            var onContinue = function onContinue() {
              var targetIndex = levels.findIndex(function (_ref) {
                var level = _ref.level;
                return level === child.level;
              });
              updateState(_extends({}, state, {
                level: levels[targetIndex + 1].level,
                parent: child.id,
                highlightedIndex: 0,
                selected: null,
                searchQuery: ''
              }));

              if (onTraverseLevel !== undefined) {
                onTraverseLevel(child, Direction.desc);
              }
            };

            var onSearch = function onSearch() {
              selectDatum(child);
            };

            var onMouseEnter = function onMouseEnter() {
              if (onHover) {
                onHover(child);
              }
            };

            var resultElm = disallowSelectionLevels && disallowSelectionLevels.includes(levels[index].level) ? React__default.createElement(SearchButton, {
              onClick: onContinue,
              onMouseEnter: onMouseEnter,
              onMouseLeave: onMouseLeave,
              className: 'react-panel-search-list-item traverse-only',
              style: {
                paddingLeft: depth * resultsIdentation + 'rem',
                paddingRight: resultsIdentation + 'rem'
              }
            }, React__default.createElement("span", {
              dangerouslySetInnerHTML: {
                __html: child.title.replace(safeQuery, function (match) {
                  return "<strong>" + match + "</strong>";
                })
              }
            }), keywordResultElm) : React__default.createElement(SearchButton, {
              onClick: onSearch,
              onMouseEnter: onMouseEnter,
              onMouseLeave: onMouseLeave,
              className: 'react-panel-search-list-item',
              style: {
                paddingLeft: depth * resultsIdentation + 'rem',
                paddingRight: resultsIdentation + 'rem'
              }
            }, React__default.createElement("span", {
              dangerouslySetInnerHTML: {
                __html: child.title.replace(safeQuery, function (match) {
                  return "<strong>" + match + "</strong>";
                })
              }
            }), keywordResultElm);
            elms.push(React__default.createElement("li", {
              className: 'react-panel-search-list-item-container',
              key: 'search-' + child.title + child.id
            }, resultElm, childList));
          }
        }
      });
      return elms;
    };

    [].concat(levels, [{
      level: null,
      data: topLevelItems
    }]).forEach(function (_ref2, i) {
      var level = _ref2.level,
          data = _ref2.data;
      sortBy(data, ['name']).forEach(function (datum) {
        var keywordMatch;
        var keywordResultElm;

        if (datum.keywords && datum.keywords.length) {
          var matchingKeywords = datum.keywords.filter(function (k) {
            return k.toLowerCase().includes(state.searchQuery.toLowerCase());
          });
          var nonMatchingKeywords = datum.keywords.filter(function (k) {
            return !k.toLowerCase().includes(state.searchQuery.toLowerCase());
          });
          keywordMatch = matchingKeywords.length !== 0;
          keywordResultElm = matchingKeywordFormatter ? matchingKeywordFormatter(matchingKeywords, nonMatchingKeywords, state.searchQuery) : null;
        } else {
          keywordMatch = false;
          keywordResultElm = null;
        }

        if (datum.always_show) {
          keywordMatch = true;
        }

        if (!renderedIds.includes(datum.id) && (datum.title.toLowerCase().includes(state.searchQuery.toLowerCase()) || keywordMatch) && (!maxResults || renderedIds.length < maxResults)) {
          renderedIds.push(datum.id);
          var childElms;

          if (levels[i + 1] && levels[i + 1].data) {
            childElms = getChildren(i + 1, datum.id, 1);
          } else {
            childElms = null;
          }

          var childList = childElms && childElms.length ? React__default.createElement("ul", {
            className: 'react-panel-search-list-inner-container'
          }, childElms) : null;

          var onContinue = function onContinue() {
            var targetIndex = levels.findIndex(function (target) {
              return target.level === level;
            });
            updateState(_extends({}, state, {
              level: levels[targetIndex + 1].level,
              parent: datum.id,
              highlightedIndex: 0,
              selected: null,
              searchQuery: ''
            }));

            if (onTraverseLevel !== undefined) {
              onTraverseLevel(datum, Direction.desc);
            }
          };

          var onSearch = function onSearch() {
            selectDatum(datum);
          };

          var onMouseEnter = function onMouseEnter() {
            if (onHover) {
              onHover(datum);
            }
          };

          var resultElm = disallowSelectionLevels && disallowSelectionLevels.includes(level) ? React__default.createElement(SearchButton, {
            onClick: onContinue,
            onMouseEnter: onMouseEnter,
            onMouseLeave: onMouseLeave,
            className: 'react-panel-search-list-item traverse-only',
            style: {
              paddingLeft: resultsIdentation + 'rem',
              paddingRight: resultsIdentation + 'rem'
            }
          }, React__default.createElement("span", {
            dangerouslySetInnerHTML: {
              __html: datum.title.replace(safeQuery, function (match) {
                return "<strong>" + match + "</strong>";
              })
            }
          }), keywordResultElm) : React__default.createElement(SearchButton, {
            onClick: onSearch,
            onMouseEnter: onMouseEnter,
            onMouseLeave: onMouseLeave,
            className: 'react-panel-search-list-item',
            style: {
              paddingLeft: resultsIdentation + 'rem',
              paddingRight: resultsIdentation + 'rem'
            }
          }, React__default.createElement("span", {
            dangerouslySetInnerHTML: {
              __html: datum.title.replace(safeQuery, function (match) {
                return "<strong>" + match + "</strong>";
              })
            }
          }), keywordResultElm);
          filteredElms.push(React__default.createElement("li", {
            className: 'react-panel-search-list-item-container',
            key: 'search-' + datum.title + datum.id
          }, resultElm, childList));
        }
      });
    });

    if (filteredElms.length === 0) {
      var noResultsText = noResultsFoundFormatter ? noResultsFoundFormatter(state.searchQuery) : "No results found for " + state.searchQuery;
      filteredElms.push(React__default.createElement("li", {
        className: 'react-panel-search-list-item-container react-panel-search-list-no-results',
        key: 'search-results-no-reasults-key'
      }, React__default.createElement(NoResults, null, noResultsText)));
    }

    listOutput = React__default.createElement("ul", {
      className: 'react-panel-search-list-root-container'
    }, filteredElms);
  } else {
    var targetIndex = levels.findIndex(function (_ref3) {
      var level = _ref3.level;
      return level === state.level;
    });
    var listItems = levels[targetIndex].data.filter(function (_ref4) {
      var parent_id = _ref4.parent_id;
      return parent_id === state.parent;
    }).map(function (d) {
      var onContinue = function onContinue() {
        updateState(_extends({}, state, {
          level: levels[targetIndex + 1].level,
          parent: d.id,
          highlightedIndex: 0
        }));

        if (onTraverseLevel !== undefined) {
          onTraverseLevel(d, Direction.desc);
        }
      };

      var onSearch = function onSearch() {
        if (disallowSelectionLevels && disallowSelectionLevels.includes(levels[targetIndex].level)) {
          onContinue();
        } else {
          selectDatum(d);
        }
      };

      var ArrowButton = disallowSelectionLevels && disallowSelectionLevels.includes(levels[targetIndex].level) ? TraverseOnlyButton : NextButton;
      var className = disallowSelectionLevels && disallowSelectionLevels.includes(levels[targetIndex].level) ? 'react-panel-search-list-item traverse-only' : 'react-panel-search-list-item';
      var continueButton = targetIndex !== levels.length - 1 ? React__default.createElement(ArrowButton, {
        className: 'react-panel-search-next-button',
        onClick: onContinue,
        dangerouslySetInnerHTML: {
          __html: chevronSVG$1
        }
      }) : null;

      var onMouseEnter = function onMouseEnter() {
        if (onHover) {
          onHover(d);
        }
      };

      var count = showCount && targetIndex !== levels.length - 1 ? "(" + levels[targetIndex + 1].data.filter(function (_ref5) {
        var parent_id = _ref5.parent_id;
        return parent_id === d.id;
      }).length + ")" : null;
      return React__default.createElement(PanelItem, {
        key: d.id,
        className: 'react-panel-search-panel-item-container'
      }, React__default.createElement(PanelButton, {
        onClick: onSearch,
        className: className,
        onMouseEnter: onMouseEnter,
        onMouseLeave: onMouseLeave
      }, d.title, " ", count), " ", continueButton);
    });
    var topLevelListItems;

    if (topLevelItems.length && targetIndex === 0) {
      var items = topLevelItems.map(function (d) {
        var onMouseEnter = function onMouseEnter() {
          if (onHover) {
            onHover(d);
          }
        };

        return React__default.createElement(PanelItem, {
          key: d.id,
          className: 'react-panel-search-panel-item-container'
        }, React__default.createElement(PanelButton, {
          onClick: function onClick() {
            return selectDatum(d);
          },
          className: 'react-panel-search-list-item',
          onMouseEnter: onMouseEnter,
          onMouseLeave: onMouseLeave
        }, d.title));
      });
      topLevelListItems = items.length ? React__default.createElement("ul", {
        className: 'react-panel-search-panel-list-top-items-container'
      }, items) : null;
    } else {
      topLevelListItems = null;
    }

    var parentDatum = parent === null || targetIndex === 0 ? undefined : levels[targetIndex - 1].data.find(function (_ref6) {
      var id = _ref6.id;
      return id === state.parent;
    });
    var titleText = topLevelTitle ? React__default.createElement("span", null, topLevelTitle) : null;
    var breadCrumb = !parentDatum ? React__default.createElement(TitleOuter, {
      className: 'react-panel-search-current-tier-static-title-outer'
    }, React__default.createElement(Title, {
      className: 'react-panel-search-current-tier-title'
    }, titleText)) : React__default.createElement(BreadCrumbOuter, {
      className: 'react-panel-search-current-tier-breadcrumb-outer'
    }, React__default.createElement(Title, {
      className: 'react-panel-search-current-tier-title',
      onClick: function onClick() {
        updateState(_extends({}, state, {
          level: levels[targetIndex - 1].level,
          parent: parentDatum.parent_id,
          highlightedIndex: 0
        }));

        if (onTraverseLevel !== undefined) {
          onTraverseLevel(parentDatum, Direction.asc);
        }
      }
    }, React__default.createElement(NavButton, {
      className: 'react-panel-search-previous-button',
      dangerouslySetInnerHTML: {
        __html: chevronSVG$1
      }
    }), React__default.createElement("span", {
      className: 'react-panel-search-current-tier-text'
    }, parentDatum.title)));
    listOutput = React__default.createElement(React__default.Fragment, null, topLevelListItems, breadCrumb, React__default.createElement("ul", {
      className: 'react-panel-search-panel-list-root-container' + (topLevelListItems ? 'react-panel-search-panel-list-has-top-level-items' : '')
    }, listItems));
  }

  var handleKeyDown = function handleKeyDown(e) {
    if (e.which === 40 || e.keyCode === 40) {
      updateState(_extends({}, state, {
        highlightedIndex: state.highlightedIndex + 1
      }));
    } else if (e.which === 38 || e.keyCode === 38) {
      updateState(_extends({}, state, {
        highlightedIndex: state.highlightedIndex - 1
      }));
    } else if (e.which === 13 || e.keyCode === 13) {
      var node = resultsRef.current;

      if (node) {
        var highlightedElm = node.querySelector('li .react-panel-search-highlighted-item');

        if (highlightedElm) {
          highlightedElm.click();

          if (!highlightedElm.classList.contains('traverse-only')) {
            var focusedInput = document.activeElement;

            if (focusedInput) {
              focusedInput.blur();
            }
          }
        }
      }
    }
  };

  var searchResults = state.isOpen ? React__default.createElement(SearchResults, {
    ref: resultsRef,
    className: 'react-panel-search-search-results'
  }, listOutput) : null;
  var selectedClass = state.selected ? ' react-panel-search-has-selection' : '';
  return React__default.createElement(Container, {
    ref: rootRef,
    className: 'react-panel-search-root-container' + selectedClass,
    style: {
      zIndex: state.isOpen ? 2000 : undefined
    }
  }, React__default.createElement(SearchBar$1, {
    className: 'react-panel-search-search-bar'
  }, React__default.createElement(StandardSearch, {
    placeholder: state.selected ? state.selected.title : defaultPlaceholderText,
    setSearchQuery: function setSearchQuery(val) {
      return updateState(_extends({}, state, {
        searchQuery: val,
        level: levels[0].level,
        parent: null,
        highlightedIndex: 0
      }));
    },
    initialQuery: '',
    onClear: clearSearch,
    hasSelection: state.selected ? true : false,
    neverEmpty: neverEmpty,
    handleKeyDown: handleKeyDown,
    onFocus: function onFocus() {
      return updateState(_extends({}, state, {
        isOpen: true
      }));
    },
    isOpen: state.isOpen,
    setIsOpen: function setIsOpen(isOpen) {
      return updateState(_extends({}, state, {
        isOpen: isOpen
      }));
    },
    focusOnRender: focusOnRender
  })), searchResults);
});

var PanelSearch = function PanelSearch(props) {
  var data = props.data,
      onSelect = props.onSelect,
      onHover = props.onHover,
      selectedValue = props.selectedValue,
      topLevelTitle = props.topLevelTitle,
      disallowSelectionLevels = props.disallowSelectionLevels,
      onTraverseLevel = props.onTraverseLevel,
      defaultPlaceholderText = props.defaultPlaceholderText,
      showCount = props.showCount,
      resultsIdentation = props.resultsIdentation,
      neverEmpty = props.neverEmpty,
      maxResults = props.maxResults,
      focusOnRender = props.focusOnRender,
      noResultsFoundFormatter = props.noResultsFoundFormatter,
      matchingKeywordFormatter = props.matchingKeywordFormatter,
      onClose = props.onClose;
  var topLevelItems = [];
  var levels = [];
  sortBy(data, function (_ref) {
    var title = _ref.title;
    return title.toLowerCase();
  }).forEach(function (datum) {
    if (datum.level !== null) {
      var targetIndex = levels.findIndex(function (_ref2) {
        var level = _ref2.level;
        return level === datum.level;
      });

      if (targetIndex === -1) {
        levels.push({
          level: datum.level,
          data: [datum]
        });
      } else {
        levels[targetIndex].data.push(datum);
      }
    } else {
      topLevelItems.push(datum);
    }
  });

  if (levels && levels.length) {
    var sortedLevels = sortBy(levels, ['level']);
    return React__default.createElement(Root, {
      levels: sortedLevels,
      topLevelItems: topLevelItems,
      onSelect: onSelect,
      onHover: onHover,
      onTraverseLevel: onTraverseLevel,
      selectedValue: selectedValue ? selectedValue : null,
      topLevelTitle: topLevelTitle,
      disallowSelectionLevels: disallowSelectionLevels,
      defaultPlaceholderText: defaultPlaceholderText ? defaultPlaceholderText : 'Search',
      showCount: showCount ? showCount : false,
      resultsIdentation: resultsIdentation !== undefined ? resultsIdentation : 1,
      neverEmpty: neverEmpty ? neverEmpty : false,
      maxResults: maxResults ? maxResults : null,
      focusOnRender: focusOnRender ? focusOnRender : false,
      noResultsFoundFormatter: noResultsFoundFormatter,
      matchingKeywordFormatter: matchingKeywordFormatter,
      onClose: onClose ? onClose : function () {}
    });
  } else {
    return null;
  }
};

module.exports = PanelSearch;
//# sourceMappingURL=index.js.map
